##  Step 2: Enable Discovered Flows in SAP LeanIX
  1. In SAP LeanIX, go to Administration > Integrations > SAP Discovery > Capabilities.
  2. Under Additional Capabilities, select Discovered Flow.
  3. Choose Save.
The integration automatically starts a discovery sync.
